MCD triple_N11
Affecter ( projet, employé u1, site u1 )

- Le champ projet fait partie de la clé primaire de la table. Sa table d'origine (Projet) ayant été supprimée, il n'est pas considéré comme clé étrangère.
- Le champ employé fait partie de la clé primaire de la table. Sa table d'origine (Employé) ayant été supprimée, il n'est pas considéré comme clé étrangère. Il obéit par contre à la contrainte d'unicité 1.
- Le champ site est un simple attribut. Il a migré directement à partir de l'entité Site en perdant son caractère identifiant. Cependant, comme la table créée à partir de cette entité a été supprimée, il n'est pas considéré comme clé étrangère. Il obéit par contre à la contrainte d'unicité 1.

NB. Les tables Employé, Projet et Site ont été supprimées car elles étaient réduites à la clé primaire de leur entité d'origine. Pour conserver de telles tables, préfixez d'un « + » la définition des entités d'origine.